==> haskell-wl-pprint-terminfo-3.7.1.4-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-AcQwr1xrtlGGuwMDchyS9i
key: wl-pprint-terminfo-3.7.1.4-AcQwr1xrtlGGuwMDchyS9i
license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
abi: 111439c4166d53b176f02fa81a9a4dc2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-terminfo-3.7.1.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/wl-pprint-terminfo-3.7.1.4
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-AcQwr1xrtlGGuwMDchyS9i
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz terminfo-0.4.0.2
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    wl-pprint-extras-3.5.0.5-95h67TeVCzjbcAwZjWS3P
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-58Hxm4cUixj9Woww17ObrT
key: wl-pprint-terminfo-3.7.1.4-58Hxm4cUixj9Woww17ObrT
license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
abi: 12bdcc38c7e93fb019563362cfe3273f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/wl-pprint-terminfo-3.7.1.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/wl-pprint-terminfo-3.7.1.4
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-58Hxm4cUixj9Woww17ObrT
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz terminfo-0.4.0.2
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    wl-pprint-extras-3.5.0.5-GWVh3ldfpEWJFGLyIK6q3A
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
